/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DummyDataSource.java 527 2006-05-28 19:55:51Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.ds;

import org.objectweb.easybeans.dbpool.ConnectionManager;
import org.objectweb.easybeans.transaction.JTransactionManager;

/**
 * Defines a dummy datasource implementation based on HSQL in memory server.
 * @author florent
 *
 */
public class DummyDataSource extends ConnectionManager {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 2850630613613046426L;

    /**
     * Default pool size.
     */
    private static final int DEFAULT_POOLSIZE = 30;

    /**
     * Default prepared statement.
     */
    private static final int DEFAULT_PSTMT = 10;


    /**
     * Constructor.<br>
     * Init the driver.
     * @param name used for the instance name.
     */
    public DummyDataSource(final String name) {
        super();
        setDatasourceName(name); // set datasource name
        setDSName(name); // set jndi name
        setUrl("jdbc:hsqldb:hsql://localhost:9001/" + name);

        try {
            setClassName("org.hsqldb.jdbcDriver");
        } catch (ClassNotFoundException e) {
            throw new IllegalStateException("cannot load jdbc driver", e);
        }
        setUserName("sa");
        setPassword("");
        setTransactionIsolation("default");
        setPoolMax(DEFAULT_POOLSIZE);
        setPstmtMax(DEFAULT_PSTMT);
        setTm(JTransactionManager.getTransactionManager());
    }

}
