/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SecurityPermissionTester.java 897 2006-07-20 11:43:13Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.security;

import static org.testng.Assert.fail;

import javax.annotation.security.RunAs;
import javax.ejb.EJBAccessException;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;
import org.objectweb.easybeans.tests.common.ejbs.base.security.ItfSecurityRoles;

/**
 * Test if the policies work property.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 *
 */
@RunAs("secondaryrole")
public abstract class SecurityPermissionTester implements ItfSecurityPermissionTester {

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(SecurityPermissionTester.class);


   /**
     * The bean used to test the roles.
     * @return the bean.
     */
    public abstract ItfSecurityRoles getBean();


    /**
     * Verifies if the permitAll police works.
     */
    public void testPermitAll() {
        getBean().permitAllAttribute();
    }

    /**
     * Verifies if the denyAll police works.
     */
    public void testDenyAll() {
        try{
            getBean().denyAllAttribute();
            fail("The method has a denyAll annotation, so the bean cannot call this method.");
        }catch(EJBAccessException e){
            logger.debug("The bean threw an expected exception {0}", e);
        }
    }

    /**
     * Verifies if the allowedRoles police for two roles(the role specified in
     * the RunAs and other role) works.
     */
    public void testAllowedRolesWithTwoRoles() {
        getBean().permitTwoRoles();
    }

    /**
     * Verifies if the allowedRoles police for one role(the role that is not
     * defined in the RunAs) works. The method must throw an exception.
     */
    public void testAllowedRolesWithOneRole() {
        try {
            getBean().permitOneRole();
            fail("The method has an allowsRoles annotation that does not contains the value "
                    + "in secondaryrole defined, so the bean cannot call this method.");
        } catch (EJBAccessException e) {
            logger.debug("The bean threw an expected exception {0}", e);
        }
    }


}
