/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SLSBResourceRefXMLInjection00.java 547 2006-05-30 13:50:43Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.resourceref;

import static org.objectweb.easybeans.tests.common.helper.ContextHelper.checkResource;

import java.net.URL;

import javax.annotation.Resource;
import javax.ejb.EJBContext;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;
import javax.jms.ConnectionFactory;
import javax.jms.QueueConnectionFactory;
import javax.jms.TopicConnectionFactory;
import javax.mail.Session;
import javax.sql.DataSource;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfResourceEnvRef00;

/**
 * This bean is used to test injection of resource references by xml descriptors with the injection-target tag.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
@Stateless(name = "SLSBResourceRefXMLInjection00")
@Remote(ItfResourceEnvRef00.class)
public class SLSBResourceRefXMLInjection00 implements ItfResourceEnvRef00 {

    /**
     * SessionContext.
     */
    @Resource
    private SessionContext sessionContext;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private DataSource ds00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private ConnectionFactory cf00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private QueueConnectionFactory qcf00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private TopicConnectionFactory tcf00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private Session mail00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private URL url00;

    /**
     * The reference must be injected by the container using
     * injection-target(XML).
     */
    private EJBContext ctx00;

    /**
     * Checks the jdbc reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkJDBC() {
        checkResource(sessionContext, ds00, "jdbc/ds00");
    }

    /**
     * Checks the jms reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkJMSConFactory() {
        checkResource(sessionContext, cf00, "jms/cf00");

    }

    /**
     * Checks the jms reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkJMSQueueConFactory() {
        checkResource(sessionContext, qcf00, "jms/qcf00");
    }

    /**
     * Checks the jms reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkJMSTopicConFactory() {
        checkResource(sessionContext, tcf00, "jms/tcf00");

    }

    /**
     * Checks the mail session reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkMailSession() {
        checkResource(sessionContext, mail00, "mail/mail00");
    }

    /**
     * Checks the url reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkUrl() {
        checkResource(sessionContext, url00, "url/url00");
    }

    /**
     * Checks the ejb context reference injected by xml descriptor.
     * @input -
     * @output -
     */
    public void checkEJBContext() {
        checkResource(sessionContext, ctx00, "ejbctx/ctx00");
    }

}
