/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Semaphore.java 889 2006-07-18 13:26:27Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.resources;

/**
 * Semaphore.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class Semaphore {

    /**
     * Max value.
     */
    private int maxValue;

    /**
     *  Available places.
     */
    private int value;

    /**
     * Default constructor.
     * @param initialValue available places.
     */
    public Semaphore(final int initialValue) {
        maxValue = initialValue;
        value = initialValue;
    }

    /**
     * Decrement.
     */
    public synchronized void p() {
        while (value <= 0) {
            try {
                wait();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        value--;
    }

    /**
     * Increment.
     *
     */
    public synchronized void v() {
        value++;
        notify();
    }

    /**
     * Waits all threads to finish.
     *
     */
    public synchronized void waitAll() {
        while (maxValue != value) {
            try {
                wait();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }
}
